<hr style="height:30px"/>

### -= Languages =-

* [English](#hello)

* [Español](#hola)

<hr style="height:30px"/>

# Hello!

This repository is meant to be used to develop simple games on the [Gamelib](https://github.com/dessaya/python-gamelib) library (by [Diego Essaya](https://github.com/dessaya)).
As such, don't expect anything great. It's certainly a great way to kill off some time, though.

### The games currently developing

<br/>

* _[Nothing yet, I'm afraid!]_

### The games already completed

Or the ones that already are in the stage of v1.0.0 release or up.

* [**Picross - v1.1.0**](picross)

Playing          |           Losing          |           Creating New Game
:----------------------:|:----------------------:|:----------------------:
<img alt="picross_gameplay" src="gamelibgames/picross/img/gameplay_demo/gameplay.gif" width=250 height=300> | <img alt="picross_losing" src="gamelibgames/picross/img/gameplay_demo/losing_epicly.gif" width=250 height=300>| <img alt="picross_new_game" src="gamelibgames/picross/img/gameplay_demo/creating_new_game.gif" width=250 height=300>

* [**Minesweeper - v1.0.0**](minesweeper)

Playing          |           Mines Exploding          |           Starting Anew
:----------------------:|:----------------------:|:----------------------:
<img alt="minesweeper_gameplay" src="gamelibgames/minesweeper/img/demo/playing.gif" width=250 height=300> | <img alt="minesweeper_mines_go_boom.gif" src="gamelibgames/minesweeper/img/demo/mines_go_kaboom.gif" width=250 height=300>| <img alt="picross_new_game" src="gamelibgames/minesweeper/img/demo/resizing_and_winning.gif" width=250 height=300>

<hr style="height:40px"/>

# Hola!

Este repositorio está pensado para utilizarse para el desarrollo de juegos simples haciendo uso de la librería [Gamelib](https://github.com/dessaya/python-gamelib) (por [Diego Essaya](https://github.com/dessaya)).
Por lo tanto, no esperes nada muy complejo. Aunque es una manera magnífica de matar el tiempo.

### Los juegos actualmente en desarrollo

<br/>

* _[¡Aún nada, me temo!]_

### Los juegos ya completados

O aquellos que ya estén en fase v1.0.0 o superior.

* [**Picross (Nonograma) - v1.1.0**](picross)

Jugando          |           Perdiendo          |           Creando Nueva Partida
:----------------------:|:----------------------:|:----------------------:
<img alt="picross_gameplay" src="gamelibgames/picross/img/gameplay_demo/gameplay.gif" width=250 height=300> | <img alt="picross_perdiendo" src="gamelibgames/picross/img/gameplay_demo/losing_epicly.gif" width=250 height=300>| <img alt="picross_nueva_partida" src="gamelibgames/picross/img/gameplay_demo/creating_new_game.gif" width=250 height=300>

* [**Minesweeper (Buscaminas) - v1.0.0**](minesweeper)

Jugando          |           Minas Explotando          |           Empezando de Nuevo
:----------------------:|:----------------------:|:----------------------:
<img alt="minesweeper_gameplay" src="gamelibgames/minesweeper/img/demo/playing.gif" width=250 height=300> | <img alt="minesweeper_mines_go_boom.gif" src="gamelibgames/minesweeper/img/demo/mines_go_kaboom.gif" width=250 height=300>| <img alt="picross_new_game" src="gamelibgames/minesweeper/img/demo/resizing_and_winning.gif" width=250 height=300>